Class: CybridApiOrganization::PostSubscriptionOrganizationModel
- Inherits:
-
Object
- Object
- CybridApiOrganization::PostSubscriptionOrganizationModel
- Defined in:
- lib/cybrid_api_organization_ruby/models/post_subscription_organization_model.rb
Overview
Request body for subscription creation.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#environment ⇒ Object
The environment that the subscription is configured for.
-
#name ⇒ Object
Name provided for the subscription.
-
#recipient ⇒ Object
Recipient email address.
-
#type ⇒ Object
Type of the subscription.
-
#url ⇒ Object
URL provided for the subscription.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PostSubscriptionOrganizationModel
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ PostSubscriptionOrganizationModel
Initializes the object
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/cybrid_api_organization_ruby/models/post_subscription_organization_model.rb', line 93 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `CybridApiOrganization::PostSubscriptionOrganizationModel` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `CybridApiOrganization::PostSubscriptionOrganizationModel`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'environment') self.environment = attributes[:'environment'] else self.environment = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'url') self.url = attributes[:'url'] end if attributes.key?(:'recipient') self.recipient = attributes[:'recipient'] end end |
Instance Attribute Details
#environment ⇒ Object
The environment that the subscription is configured for.
20 21 22 |
# File 'lib/cybrid_api_organization_ruby/models/post_subscription_organization_model.rb', line 20 def environment @environment end |
#name ⇒ Object
Name provided for the subscription.
26 27 28 |
# File 'lib/cybrid_api_organization_ruby/models/post_subscription_organization_model.rb', line 26 def name @name end |
#recipient ⇒ Object
Recipient email address. Required when type is email.
32 33 34 |
# File 'lib/cybrid_api_organization_ruby/models/post_subscription_organization_model.rb', line 32 def recipient @recipient end |
#type ⇒ Object
Type of the subscription.
23 24 25 |
# File 'lib/cybrid_api_organization_ruby/models/post_subscription_organization_model.rb', line 23 def type @type end |
#url ⇒ Object
URL provided for the subscription. Required when type is webhook.
29 30 31 |
# File 'lib/cybrid_api_organization_ruby/models/post_subscription_organization_model.rb', line 29 def url @url end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 |
# File 'lib/cybrid_api_organization_ruby/models/post_subscription_organization_model.rb', line 314 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = CybridApiOrganization.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
68 69 70 |
# File 'lib/cybrid_api_organization_ruby/models/post_subscription_organization_model.rb', line 68 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 |
# File 'lib/cybrid_api_organization_ruby/models/post_subscription_organization_model.rb', line 57 def self.attribute_map { :'environment' => :'environment', :'type' => :'type', :'name' => :'name', :'url' => :'url', :'recipient' => :'recipient' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/cybrid_api_organization_ruby/models/post_subscription_organization_model.rb', line 290 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
84 85 86 87 88 89 |
# File 'lib/cybrid_api_organization_ruby/models/post_subscription_organization_model.rb', line 84 def self.openapi_nullable Set.new([ :'url', :'recipient' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 81 |
# File 'lib/cybrid_api_organization_ruby/models/post_subscription_organization_model.rb', line 73 def self.openapi_types { :'environment' => :'String', :'type' => :'String', :'name' => :'String', :'url' => :'String', :'recipient' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
265 266 267 268 269 270 271 272 273 |
# File 'lib/cybrid_api_organization_ruby/models/post_subscription_organization_model.rb', line 265 def ==(o) return true if self.equal?(o) self.class == o.class && environment == o.environment && type == o.type && name == o.name && url == o.url && recipient == o.recipient end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
385 386 387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/cybrid_api_organization_ruby/models/post_subscription_organization_model.rb', line 385 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
277 278 279 |
# File 'lib/cybrid_api_organization_ruby/models/post_subscription_organization_model.rb', line 277 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
283 284 285 |
# File 'lib/cybrid_api_organization_ruby/models/post_subscription_organization_model.rb', line 283 def hash [environment, type, name, url, recipient].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/cybrid_api_organization_ruby/models/post_subscription_organization_model.rb', line 135 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @environment.nil? invalid_properties.push('invalid value for "environment", environment cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 128 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 128.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be great than or equal to 1.') end if !@url.nil? && @url.to_s.length > 1024 invalid_properties.push('invalid value for "url", the character length must be smaller than or equal to 1024.') end if !@url.nil? && @url.to_s.length < 1 invalid_properties.push('invalid value for "url", the character length must be great than or equal to 1.') end if !@recipient.nil? && @recipient.to_s.length > 254 invalid_properties.push('invalid value for "recipient", the character length must be smaller than or equal to 254.') end if !@recipient.nil? && @recipient.to_s.length < 1 invalid_properties.push('invalid value for "recipient", the character length must be great than or equal to 1.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
361 362 363 |
# File 'lib/cybrid_api_organization_ruby/models/post_subscription_organization_model.rb', line 361 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
367 368 369 370 371 372 373 374 375 376 377 378 379 |
# File 'lib/cybrid_api_organization_ruby/models/post_subscription_organization_model.rb', line 367 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
355 356 357 |
# File 'lib/cybrid_api_organization_ruby/models/post_subscription_organization_model.rb', line 355 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/cybrid_api_organization_ruby/models/post_subscription_organization_model.rb', line 179 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @environment.nil? environment_validator = EnumAttributeValidator.new('String', ["sandbox", "production"]) return false unless environment_validator.valid?(@environment) return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["webhook", "email"]) return false unless type_validator.valid?(@type) return false if @name.nil? return false if @name.to_s.length > 128 return false if @name.to_s.length < 1 return false if !@url.nil? && @url.to_s.length > 1024 return false if !@url.nil? && @url.to_s.length < 1 return false if !@recipient.nil? && @recipient.to_s.length > 254 return false if !@recipient.nil? && @recipient.to_s.length < 1 true end |