Class: CybridApiOrganization::SubscriptionOrganizationModel

Inherits:
Object
  • Object
show all
Defined in:
lib/cybrid_api_organization_ruby/models/subscription_organization_model.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SubscriptionOrganizationModel

Initializes the object



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/cybrid_api_organization_ruby/models/subscription_organization_model.rb', line 134

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `CybridApiOrganization::SubscriptionOrganizationModel` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `CybridApiOrganization::SubscriptionOrganizationModel`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'guid')
    self.guid = attributes[:'guid']
  else
    self.guid = nil
  end

  if attributes.key?(:'organization_guid')
    self.organization_guid = attributes[:'organization_guid']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'signing_key')
    self.signing_key = attributes[:'signing_key']
  end

  if attributes.key?(:'recipient')
    self.recipient = attributes[:'recipient']
  end

  if attributes.key?(:'deliveries_failing_since')
    self.deliveries_failing_since = attributes[:'deliveries_failing_since']
  end

  if attributes.key?(:'environment')
    self.environment = attributes[:'environment']
  else
    self.environment = nil
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  else
    self.state = nil
  end

  if attributes.key?(:'failure_code')
    self.failure_code = attributes[:'failure_code']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#created_atObject

ISO8601 datetime the record was created at.



52
53
54
# File 'lib/cybrid_api_organization_ruby/models/subscription_organization_model.rb', line 52

def created_at
  @created_at
end

#deliveries_failing_sinceObject

ISO8601 datetime the deliveries started failing.



40
41
42
# File 'lib/cybrid_api_organization_ruby/models/subscription_organization_model.rb', line 40

def deliveries_failing_since
  @deliveries_failing_since
end

#environmentObject

The environment that the subscription is configured for; one of sandbox or production.



43
44
45
# File 'lib/cybrid_api_organization_ruby/models/subscription_organization_model.rb', line 43

def environment
  @environment
end

#failure_codeObject

The failure code of a subscription (if any)



49
50
51
# File 'lib/cybrid_api_organization_ruby/models/subscription_organization_model.rb', line 49

def failure_code
  @failure_code
end

#guidObject

Auto-generated unique identifier for the subscription.



19
20
21
# File 'lib/cybrid_api_organization_ruby/models/subscription_organization_model.rb', line 19

def guid
  @guid
end

#nameObject

Name provided for the subscription.



25
26
27
# File 'lib/cybrid_api_organization_ruby/models/subscription_organization_model.rb', line 25

def name
  @name
end

#organization_guidObject

The organization guid for the subscription.



22
23
24
# File 'lib/cybrid_api_organization_ruby/models/subscription_organization_model.rb', line 22

def organization_guid
  @organization_guid
end

#recipientObject

Recipient email address. Required when subscription_type is email.



37
38
39
# File 'lib/cybrid_api_organization_ruby/models/subscription_organization_model.rb', line 37

def recipient
  @recipient
end

#signing_keyObject

Subscription private signing key. Optional when subscription_type is webhook.



34
35
36
# File 'lib/cybrid_api_organization_ruby/models/subscription_organization_model.rb', line 34

def signing_key
  @signing_key
end

#stateObject

The state of the subscription; one of storing, completed, or failed.



46
47
48
# File 'lib/cybrid_api_organization_ruby/models/subscription_organization_model.rb', line 46

def state
  @state
end

#typeObject

The type of subscription.



28
29
30
# File 'lib/cybrid_api_organization_ruby/models/subscription_organization_model.rb', line 28

def type
  @type
end

#updated_atObject

ISO8601 datetime the record was last updated at.



55
56
57
# File 'lib/cybrid_api_organization_ruby/models/subscription_organization_model.rb', line 55

def updated_at
  @updated_at
end

#urlObject

The url for the subscription. Required when subscription_type is webhook.



31
32
33
# File 'lib/cybrid_api_organization_ruby/models/subscription_organization_model.rb', line 31

def url
  @url
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type



429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
# File 'lib/cybrid_api_organization_ruby/models/subscription_organization_model.rb', line 429

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = CybridApiOrganization.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



99
100
101
# File 'lib/cybrid_api_organization_ruby/models/subscription_organization_model.rb', line 99

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/cybrid_api_organization_ruby/models/subscription_organization_model.rb', line 80

def self.attribute_map
  {
    :'guid' => :'guid',
    :'organization_guid' => :'organization_guid',
    :'name' => :'name',
    :'type' => :'type',
    :'url' => :'url',
    :'signing_key' => :'signing_key',
    :'recipient' => :'recipient',
    :'deliveries_failing_since' => :'deliveries_failing_since',
    :'environment' => :'environment',
    :'state' => :'state',
    :'failure_code' => :'failure_code',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
# File 'lib/cybrid_api_organization_ruby/models/subscription_organization_model.rb', line 405

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



123
124
125
126
127
128
129
130
# File 'lib/cybrid_api_organization_ruby/models/subscription_organization_model.rb', line 123

def self.openapi_nullable
  Set.new([
    :'url',
    :'recipient',
    :'deliveries_failing_since',
    :'failure_code',
  ])
end

.openapi_typesObject

Attribute type mapping.



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/cybrid_api_organization_ruby/models/subscription_organization_model.rb', line 104

def self.openapi_types
  {
    :'guid' => :'String',
    :'organization_guid' => :'String',
    :'name' => :'String',
    :'type' => :'String',
    :'url' => :'String',
    :'signing_key' => :'String',
    :'recipient' => :'String',
    :'deliveries_failing_since' => :'Time',
    :'environment' => :'String',
    :'state' => :'String',
    :'failure_code' => :'String',
    :'created_at' => :'Time',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
# File 'lib/cybrid_api_organization_ruby/models/subscription_organization_model.rb', line 372

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      guid == o.guid &&
      organization_guid == o.organization_guid &&
      name == o.name &&
      type == o.type &&
      url == o.url &&
      signing_key == o.signing_key &&
      recipient == o.recipient &&
      deliveries_failing_since == o.deliveries_failing_since &&
      environment == o.environment &&
      state == o.state &&
      failure_code == o.failure_code &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



500
501
502
503
504
505
506
507
508
509
510
511
512
# File 'lib/cybrid_api_organization_ruby/models/subscription_organization_model.rb', line 500

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


392
393
394
# File 'lib/cybrid_api_organization_ruby/models/subscription_organization_model.rb', line 392

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



398
399
400
# File 'lib/cybrid_api_organization_ruby/models/subscription_organization_model.rb', line 398

def hash
  [guid, organization_guid, name, type, url, signing_key, recipient, deliveries_failing_since, environment, state, failure_code, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/cybrid_api_organization_ruby/models/subscription_organization_model.rb', line 212

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @guid.nil?
    invalid_properties.push('invalid value for "guid", guid cannot be nil.')
  end

  if @guid.to_s.length > 32
    invalid_properties.push('invalid value for "guid", the character length must be smaller than or equal to 32.')
  end

  if @guid.to_s.length < 32
    invalid_properties.push('invalid value for "guid", the character length must be great than or equal to 32.')
  end

  if !@organization_guid.nil? && @organization_guid.to_s.length > 32
    invalid_properties.push('invalid value for "organization_guid", the character length must be smaller than or equal to 32.')
  end

  if !@organization_guid.nil? && @organization_guid.to_s.length < 32
    invalid_properties.push('invalid value for "organization_guid", the character length must be great than or equal to 32.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 128
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 128.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be great than or equal to 1.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if !@url.nil? && @url.to_s.length > 1024
    invalid_properties.push('invalid value for "url", the character length must be smaller than or equal to 1024.')
  end

  if !@url.nil? && @url.to_s.length < 1
    invalid_properties.push('invalid value for "url", the character length must be great than or equal to 1.')
  end

  if @environment.nil?
    invalid_properties.push('invalid value for "environment", environment cannot be nil.')
  end

  if @state.nil?
    invalid_properties.push('invalid value for "state", state cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



476
477
478
# File 'lib/cybrid_api_organization_ruby/models/subscription_organization_model.rb', line 476

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



482
483
484
485
486
487
488
489
490
491
492
493
494
# File 'lib/cybrid_api_organization_ruby/models/subscription_organization_model.rb', line 482

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



470
471
472
# File 'lib/cybrid_api_organization_ruby/models/subscription_organization_model.rb', line 470

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/cybrid_api_organization_ruby/models/subscription_organization_model.rb', line 272

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @guid.nil?
  return false if @guid.to_s.length > 32
  return false if @guid.to_s.length < 32
  return false if !@organization_guid.nil? && @organization_guid.to_s.length > 32
  return false if !@organization_guid.nil? && @organization_guid.to_s.length < 32
  return false if @name.nil?
  return false if @name.to_s.length > 128
  return false if @name.to_s.length < 1
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["webhook", "email"])
  return false unless type_validator.valid?(@type)
  return false if !@url.nil? && @url.to_s.length > 1024
  return false if !@url.nil? && @url.to_s.length < 1
  return false if @environment.nil?
  return false if @state.nil?
  true
end